summaryrefslogtreecommitdiffstats
path: root/kmymoney2/widgets/kmymoneyaccounttreeforecast.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/widgets/kmymoneyaccounttreeforecast.h')
-rw-r--r--kmymoney2/widgets/kmymoneyaccounttreeforecast.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kmymoney2/widgets/kmymoneyaccounttreeforecast.h b/kmymoney2/widgets/kmymoneyaccounttreeforecast.h
index 8bde078..6965ab4 100644
--- a/kmymoney2/widgets/kmymoneyaccounttreeforecast.h
+++ b/kmymoney2/widgets/kmymoneyaccounttreeforecast.h
@@ -69,7 +69,7 @@ public:
* @param parent pointer to the parent KAccountListView object this entry should be
* added to.
* @param account const reference to MyMoneyAccount for which
* the KListView entry is constructed
* @param forecast const reference to the forecast to
* which the account belongs
* @param price price to be used to calculate value (defaults to 1)
@@ -86,7 +86,7 @@ public:
* @param parent pointer to the parent KAccountListView object this entry should be
* added to.
* @param account const reference to MyMoneyAccount for which
* the KListView entry is constructed
* @param forecast const reference to the forecast to
* which the account belongs
* @param security const reference to the security used to show the value. Usually
@@ -94,7 +94,7 @@ public:
* @param name name of the account to be used instead of the one stored with @p account
* If empty, the one stored with @p account will be used. Default: empty
*/
- KMyMoneyAccountTreeForecastItem(KListView *parent, const MyMoneyAccount& account, const MyMoneyForecast &forecast, const MyMoneySecurity& security = MyMoneySecurity(), const TQString& name = TQString());
+ KMyMoneyAccountTreeForecastItem(TDEListView *parent, const MyMoneyAccount& account, const MyMoneyForecast &forecast, const MyMoneySecurity& security = MyMoneySecurity(), const TQString& name = TQString());
~KMyMoneyAccountTreeForecastItem();
@@ -69,7 +69,7 @@ public:
* added to.
* @param account const reference to MyMoneyAccount for which
- * the KListView entry is constructed
+ * the TDEListView entry is constructed
* @param forecast const reference to the forecast to
* which the account belongs
@@ -86,7 +86,7 @@ public:
* added to.
* @param account const reference to MyMoneyAccount for which
- * the KListView entry is constructed
+ * the TDEListView entry is constructed
* @param forecast const reference to the forecast to
* which the account belongs